
# Type: related mappings


A list of terms from different schemas or terminology systems that have related meaning.

URI: [meta:related_mappings](https://w3id.org/biolink/biolinkml/meta/related_mappings)


## Domain and Range

None ->  <sub>0..*</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents

 *  is_a: [mappings](mappings.md)

## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [Element](Element.md)
 * [SchemaDefinition](SchemaDefinition.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SubsetDefinition](SubsetDefinition.md)
 * [TypeDefinition](TypeDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | skos:relatedMatch |

